==> pylucene-9.7.0-src.tar.gz: pylucene-9.7.0/extensions/src/java/org/apache/pylucene/search/similarities/PythonPerFieldSimilarityWrapper.java <==
/* ====================================================================
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

package org.apache.pylucene.search.similarities;

import org.apache.lucene.search.similarities.Similarity;
import org.apache.lucene.search.similarities.PerFieldSimilarityWrapper;


public class PythonPerFieldSimilarityWrapper extends PerFieldSimilarityWrapper {

    private long pythonObject;

    public PythonPerFieldSimilarityWrapper()
    {
    }

    public void pythonExtension(long pythonObject)
    {
        this.pythonObject = pythonObject;
    }
    public long pythonExtension()
    {
        return this.pythonObject;
    }

    public void finalize()
        throws Throwable
    {
        pythonDecRef();
    }

    public native void pythonDecRef();

    /**
     * Returns a {@link Similarity} for scoring a field.
     */
    @Override
    public native Similarity get(String name);
}

==> pylucene-10.0.0-src.tar.gz: pylucene-10.0.0/extensions/src/java/org/apache/pylucene/search/similarities/PythonPerFieldSimilarityWrapper.java <==
/* ====================================================================
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

package org.apache.pylucene.search.similarities;

import org.apache.lucene.search.similarities.Similarity;
import org.apache.lucene.search.similarities.PerFieldSimilarityWrapper;
import org.apache.pylucene.ref.PythonObject;
import org.apache.pylucene.ref.PythonObjectManager;

public class PythonPerFieldSimilarityWrapper extends PerFieldSimilarityWrapper {

    private PythonObject pythonObject;

    public PythonPerFieldSimilarityWrapper()
    {
    }

    public void pythonExtension(long pythonObject)
    {
        this.pythonObject = PythonObjectManager.register(pythonObject);
    }
    public long pythonExtension()
    {
        return this.pythonObject.pythonObject;
    }

    /**
     * Returns a {@link Similarity} for scoring a field.
     */
    @Override
    public native Similarity get(String name);
}
